|levitate_logo|
===============
.. image:: https://img.shields.io/travis/com/AppliedAcousticsChalmers/levitate/master.svg?label=tests
    :target: https://travis-ci.com/AppliedAcousticsChalmers/levitate

.. image:: https://img.shields.io/codecov/c/github/AppliedAcousticsChalmers/levitate/master.svg
    :target: https://codecov.io/gh/AppliedAcousticsChalmers/levitate

.. image:: https://img.shields.io/pypi/v/levitate.svg
    :target: https://pypi.org/project/levitate

.. image:: https://img.shields.io/github/license/AppliedAcousticsChalmers/levitate.svg
    :target: https://github.com/AppliedAcousticsChalmers/levitate/blob/master/LICENSE.txt

.. image:: https://img.shields.io/github/last-commit/AppliedAcousticsChalmers/levitate.svg
    :target: https://github.com/AppliedAcousticsChalmers/levitate

Welcome to the Levitate_ research project python toolbox.
The primary goal of this toolbox is to provide a collection of algorithms and design patterns to aid researchers working with acoustic levitation and related topics, e.g. mid-air haptic feedback or parametric audio.

- **Project Website**: http://www.levitateproject.org
- **Source code and issue tracker**: https://github.com/AppliedAcousticsChalmers/levitate
- **Documentation**: https://appliedacousticschalmers.github.io/levitate

Installation
------------
Depending on your needs the package can be installed from multiple sources.
The easiest is to use pip to install the latest stable release from PyPI::

    pip install levitate

You can also install more recent versions directly from github::

    pip install git+https://github.com/AppliedAcousticsChalmers/levitate.git

To contribute to the development the recommended installation is to clone the repository and use conda to get the requirements in a new virtual environment::

    git clone https://github.com/AppliedAcousticsChalmers/levitate.git
    cd levitate
    conda env create

....

.. image:: https://raw.githubusercontent.com/AppliedAcousticsChalmers/levitate/master/docs/eu_logo.jpg
    :align: left

This project has received funding from the European Union’s Horizon 2020 research and innovation programme under grant agreement No 737087.

|


.. |levitate_logo| image:: https://raw.githubusercontent.com/AppliedAcousticsChalmers/levitate/master/docs/levitate_logo.png
    :alt: Levitate

.. _Levitate: http://www.levitateproject.org